pyramid_fullauth
================

.. image:: https://img.shields.io/pypi/v/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/pyramid_fullauth/badge/?version=v2.0.2
    :target: https://readthedocs.org/projects/pyramid_fullauth/?badge=v2.0.2
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/dm/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/wheel/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Wheel Status

.. image:: https://img.shields.io/pypi/l/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: License

Pyramid fullauth's provides full user registration and management functionality for
`pyramid <http://docs.pylonsproject.org/en/latest/docs/pyramid.html>`_ based web applications.


Release
=======

Install pipenv and --dev dependencies first, Then run:

.. code-block::

    pipenv run tbump [NEW_VERSION]